@@ -54,8 +54,8 @@ downloads, installation and source code.
 
 __Conventions__  = 'CF-1.6'
 __author__       = 'David Hassell'
-__date__         = '2017-07-24'
-__version__      = '2.0.2'
+__date__         = '2017-08-01'
+__version__      = '2.0.3'
 
 from distutils.version import StrictVersion
 import imp
@@ -85,7 +85,7 @@ from .domainancillary      import DomainAncillary
 from .domainaxis           import DomainAxis
 from .field                import Field, FieldList
 from .fieldancillary       import FieldAncillary
-from .read                 import read, read1
+from .read                 import read, read1, read_field
 from .write                import write
 from .units                import Units
 from .cfdatetime           import Datetime, dt
