@@ -134,7 +134,6 @@ data array
     def __init__(self, subarray=None, flip=None, location=None,
                  shape=None, Units=None, part=None, axes=None,
                  fill=None):
-#                 compressed_axes=None):
         ''' 
 
 **Initialization**
@@ -447,9 +446,7 @@ False
     # ----------------------------------------------------------------
     @property
     def in_file(self):
-        '''
-
-True if and only if the partition's sub-array is on disk as opposed to
+        '''True if and only if the partition's sub-array is on disk as opposed to
 in memory.
 
 :Examples:
@@ -460,12 +457,13 @@ True
 >>> p.on_disk
 False
 
-'''
+        '''
         return self.on_disk and not self.in_temporary_file
     #--- End: if
 
     @property
-    def dtype(self):        
+    def dtype(self):
+        '''The data type of the master array'''
         return self.config['dtype']
     #--- End: def
 
@@ -496,6 +494,13 @@ False
 
     @property
     def nbytes(self):
+        '''The size in bytes of the subarray.
+
+The size takes into account the datatype and assumes that there is a
+boolean mask, unless it can be ascertained that there isn't
+one.
+
+        '''
         dtype = self.config['dtype']
         if dtype is None:
             return None
@@ -863,8 +868,6 @@ otherwise a memory leak could occur. For example:
             
         len_p_axes = len(p_axes)
 
-
-        
         if not self.in_memory:
             # --------------------------------------------------------
             # The sub-array is not in memory.
