@@ -72,7 +72,7 @@ longer required.
 
 :Returns:
 
-    out : float
+    out: `float`
         The amount of available physical memory in bytes.
 
 :Examples:
@@ -115,7 +115,7 @@ The amount of available physical memory.
 
 :Returns:
 
-    out : float
+    out: `float`
         The amount of available physical memory in bytes.
 
 :Examples:
@@ -146,7 +146,7 @@ process has completed.
 
 :Returns:
 
-    out : float
+    out: `float`
         The amount of free memory in bytes.
 
 :Examples:
@@ -198,13 +198,13 @@ def FM_THRESHOLD():
 
 The amount of memory which is kept free as a temporary work space.
 
+.. seealso:: `cf.CHUNKSIZE`, `cf.MINNCFM`
+
 :Returns:
 
-    out : float
+    out: `float`
         The amount of memory in bytes.
 
-.. seealso:: `cf.CHUNKSIZE`, `cf.MINNCFM`
-
 :Examples:
 
 >>> cf.FM_THRESHOLD()
@@ -225,21 +225,25 @@ The memory chunk size in bytes for data storage and processing.
 When setting the chunk size, the amount of minimum amount of memory to
 be kept free as a temporary work space is also updated.
 
+.. seealso:: `cf.MINNCFM`
+
+:Examples 1:
+
+>>> current_chunksize = cf.CHUNKSIZE()
+
 :Parameters:
 
-    size : int, optional
+    size: `int`, optional
         The new chunk size in bytes. The default is to not change the
         current value.
 
 :Returns:
 
-    out : float
+    out: `float`
         The value prior to the change, or the current value if no new
         value was specified.
 
-.. seealso:: `cf.MINNCFM`
-
-:Examples:
+:Examples 2:
 
 >>> cf.CHUNKSIZE()
 57095864.32
@@ -273,6 +277,8 @@ space.
 
 A chunk of memory is the amount of memory set by `cf.CHUNKSIZE`.
  
+.. seealso:: `cf.CHUNKSIZE`
+
 :Parameters:
 
     arg : int, optional
@@ -281,12 +287,10 @@ A chunk of memory is the amount of memory set by `cf.CHUNKSIZE`.
 
 :Returns:
 
-    out : int
+    out: `int`
         The value prior to the change, or the current value if no new
         value was specified.
 
-.. seealso:: `cf.CHUNKSIZE`
-
 :Examples:
 
 >>> cf.MINNCFM()
@@ -329,7 +333,7 @@ not exist.
 
 :Returns:
 
-    out : str
+    out: `str`
         The directory prior to the change, or the current directory if
         no new value was specified.
 
@@ -372,6 +376,9 @@ of concurrently open files.
 Note that closed files will be automatically reopened if subsequently
 needed by a variable to access its data array.
 
+.. seealso:: `cf.close_files`, `cf.close_one_file`, `cf.open_files`,
+             `cf.open_files_threshold_exceeded`
+
 :Parameters:
 
     arg : float, optional
@@ -380,13 +387,10 @@ needed by a variable to access its data array.
 
 :Returns:
 
-    out : float
+    out: `float`
         The value prior to the change, or the current value if no new
         value was specified.
 
-.. seealso:: `cf.close_files`, `cf.close_one_file`, `cf.open_files`,
-             `cf.open_files_threshold_exceeded`
-
 :Examples:
 
 >>> cf.OF_FRACTION()
@@ -581,13 +585,13 @@ The threshold is defined as a fraction of the maximum possible number
 of concurrently open files (an operating system dependent amount). The
 fraction is retrieved and set with the `OF_FRACTION` function.
 
+.. seealso:: `cf.close_files`, `cf.close_one_file`, `cf.open_files`
+
 :Returns:
 
-    out : bool
+    out: `bool`
         Whether or not the number of open files exceeds the threshold.
 
-.. seealso:: `cf.close_files`, `cf.close_one_file`, `cf.open_files`
-
 :Examples:
 
 In this example, the number of open files is 75% of the maximum
@@ -620,13 +624,13 @@ The threshold is defined as a fraction of the maximum possible number
 of concurrently open files (an operating system dependent amount). The
 fraction is retrieved and set with the `OF_FRACTION` function.
 
+.. seealso:: `cf.close_files`, `cf.close_one_file`, `cf.open_files`
+
 :Returns:
 
-    out : bool
+    out: `bool`
         Whether or not the number of open files exceeds the threshold.
 
-.. seealso:: `cf.close_files`, `cf.close_one_file`, `cf.open_files`
-
 :Examples:
 
 In this example, the number of open files is 75% of the maximum
@@ -656,6 +660,9 @@ needed by a variable to access the sub-array.
 
 If there are no appropriate open files then no action is taken.
 
+.. seealso:: `cf.close_one_file`, `cf.open_files`,
+             `cf.open_files_threshold_exceeded`
+
 :Parameters:
 
     file_format : str, optional
@@ -667,9 +674,6 @@ If there are no appropriate open files then no action is taken.
 
     None
 
-.. seealso:: `cf.close_one_file`, `cf.open_files`,
-             `cf.open_files_threshold_exceeded`
-
 :Examples:
 
 >>> cf.close_files()
@@ -703,6 +707,9 @@ subsequently needed by a variable to access the sub-array.
 
 If there are no appropriate open files then no action is taken.
 
+.. seealso:: `cf.close_files`, `cf.open_files`,
+             `cf.open_files_threshold_exceeded`
+
 :Parameters:
 
     file_format : str, optional
@@ -714,9 +721,6 @@ If there are no appropriate open files then no action is taken.
 
     None
 
-.. seealso:: `cf.close_files`, `cf.open_files`,
-             `cf.open_files_threshold_exceeded`
-
 :Examples:
 
 >>> cf.close_one_file()
@@ -758,6 +762,9 @@ Return the open files containing sub-arrays of master data arrays.
 By default all such files are returned, but the selection may be
 restricted to files of a particular format.
 
+.. seealso:: `cf.close_files`, `cf.close_one_file`,
+             `cf.open_files_threshold_exceeded`
+
 :Parameters:
 
     file_format : str, optional
@@ -766,7 +773,7 @@ restricted to files of a particular format.
 
 :Returns:
 
-    out : dict
+    out: `dict`
         If *file_format* is set then return a dictionary of file names
         of the specified format and their open file objects. If
         *file_format* is not set then return a dictionary for which
@@ -774,9 +781,6 @@ restricted to files of a particular format.
         would have been returned if the *file_format* parameter was
         set.
 
-.. seealso:: `cf.close_files`, `cf.close_one_file`,
-             `cf.open_files_threshold_exceeded`
-
 :Examples:
 
 >>> cf.open_files()
@@ -820,7 +824,7 @@ unchanged to the variable's *name* method.
 
 :Returns:
 
-    out : 
+    out: 
         A new variable with size 1 axes inserted into the data array.
 
 :Examples:
@@ -857,7 +861,7 @@ between ``a`` and ``b``.
 
 :Returns:
 
-    out : bool
+    out: `bool`
         Returns True if the arrays are equal, otherwise False.
 
 :Examples:
@@ -1083,8 +1087,8 @@ def parse_indices(shape, indices, cyclic=False, reverse=False, envelope=False):
                 if (start == stop or
                     (start < stop and step < 0) or
                     (start > stop and step > 0)):
-                    raise IndexError("Invalid indices %s for array with shape %s" %
-                                     (parsed_indices, shape))
+                    raise IndexError(
+"Invalid indices {} for array with shape {}".format(parsed_indices, shape))
                 if step < 0 and stop < 0:
                     stop = None
                 index = slice(start, stop, step)
@@ -1370,6 +1374,8 @@ def ATOL(*arg):
 The value of absolute tolerance for testing numerically tolerant
 equality.
 
+.. seealso:: `cf.RTOL`
+
 :Parameters:
 
     arg : int, optional
@@ -1378,12 +1384,10 @@ equality.
 
 :Returns:
 
-    out : float
+    out: `float`
         The value prior to the change, or the current value if no
         new value was specified.
 
-.. seealso:: `cf.RTOL`
-
 :Examples:
 
 >>> cf.ATOL()
@@ -1408,6 +1412,8 @@ def RTOL(*arg):
 The value of relative tolerance for testing numerically
 tolerant equality.
 
+.. seealso:: `cf.ATOL`
+
 :Parameters:
 
     arg : int, optional
@@ -1416,12 +1422,10 @@ tolerant equality.
 
 :Returns:
 
-    out : float
+    out: `float`
         The value prior to the change, or the current value if no
         new value was specified.
 
-.. seealso:: `cf.ATOL`
-
 :Examples:
 
 >>> cf.RTOL()
@@ -1475,7 +1479,7 @@ y)`` is equivalent to ``y.equals(x)``.
 
 :Returns: 
 
-    out : bool
+    out: `bool`
         Whether or not the two objects are equal.
 
 :Examples:
@@ -1599,7 +1603,7 @@ used, and in this case ``equivalent(x, y)`` is the same as
 
 :Returns: 
 
-    out : bool
+    out: `bool`
         Whether or not the two objects are equivalent.
 
 :Examples:
@@ -1663,7 +1667,7 @@ Return an iterator over an arbitrarily nested sequence.
 
 :Returns:
 
-    out : generator
+    out: generator
         An iterator over flattened sequence.
 
 :Examples:
@@ -1742,6 +1746,8 @@ The pickling is equivalent to::
    cPickle.dump(x, fh, 2)
    fh.close()
 
+.. seealso:: `cf.unpickle`
+
 :Parameters:
 
     x : 
@@ -1767,8 +1773,6 @@ The pickling is equivalent to::
     PickleError :
         If the object is not picklable.
 
-.. seealso:: `cf.unpickle`
-
 :Examples:
 
 For any picklable object, x:
@@ -1807,6 +1811,8 @@ The unpickling is equivalent to::
    x = cPickle.load(fh)
    fh.close()
 
+.. seealso:: `cf.pickle`
+
 :Parameters:
 
     filename : str
@@ -1814,7 +1820,7 @@ The unpickling is equivalent to::
 
 :Returns:
 
-    out : 
+    out: 
         The reconstituted object.
 
 :Raises:
@@ -1824,8 +1830,6 @@ The unpickling is equivalent to::
         raised when attempting to unpickle fields which were pickled
         with a different, incompatible version of cf.
 
-.. seealso:: `cf.pickle`
-
 :Examples:
 
 For any picklable object, x:
@@ -1873,18 +1877,18 @@ Return a normalized absolute version of a file name.
 
 If a string containing URL is provided then it is returned unchanged.
 
+.. seealso:: `cf.dirname`, `cf.pathjoin`, `cf.relpath`
+
 :Parameters:
 
-    filename : str
+    filename: `str`
         The name of the file.
 
 :Returns:
 
-    out : str
+    out: `str`
         The normalized absolutized version of *filename*.
  
-.. seealso:: `cf.dirname`, `cf.pathjoin`, `cf.relpath`
-
 :Examples:
 
 >>> import os
@@ -1915,22 +1919,22 @@ optional start point.
 
 If a string containing URL is provided then it is returned unchanged.
 
+.. seealso:: `cf.abspath`, `cf.dirname`, `cf.pathjoin`
+
 :Parameters:
 
-    filename : str
+    filename: `str`
         The name of the file.
 
-    start : str, optional
+    start: `str`, optional
         The start point for the relative path. By default the current
         directoty is used.
 
 :Returns:
 
-    out : str
+    out: `str`
         The relative path.
 
-.. seealso:: `cf.abspath`, `cf.dirname`, `cf.pathjoin`
-
 :Examples:
 
 >>> cf.relpath('/data/archive/file.nc')
@@ -1959,18 +1963,18 @@ Return the directory name of a file.
 If a string containing URL is provided then everything up to, but not
 including, the last slash (/) is returned.
 
+.. seealso:: `cf.abspath`, `cf.pathjoin`, `cf.relpath`
+
 :Parameters:
 
-    filename : str
+    filename: `str`
         The name of the file.
 
 :Returns:
 
-    out : str
+    out: `str`
         The directory name.
 
-.. seealso:: `cf.abspath`, `cf.pathjoin`, `cf.relpath`
-
 :Examples:
 
 >>> cf.dirname('/data/archive/file.nc')
@@ -1995,21 +1999,21 @@ Join two file path components intelligently.
 
 If either of the paths is a URL then a URL will be returned
 
+.. seealso:: `cf.abspath`, `cf.dirname`, `cf.relpath`
+
 :Parameters:
 
-    path1 : str
+    path1: `str`
         The first component of the path.
 
-    path2 : str
+    path2: `str`
         The second component of the path.
 
 :Returns:
 
-    out : str
+    out: `str`
         The joined paths.
 
-.. seealso:: `cf.abspath`, `cf.dirname`, `cf.relpath`
-
 :Examples:
 
 >>> cf.pathjoin('/data/archive', '../archive/file.nc')
@@ -2044,12 +2048,12 @@ Python, numpy and cf.
 
 :Parameters:
 
-    array : numpy.ndarray
+    array: `numpy.ndarray`
         The numpy array to be hashed. May be a masked array.
 
 :Returns:
 
-    out : int
+    out: `int`
         The hash value
 
 :Examples:
@@ -2117,7 +2121,7 @@ Inspect the attributes of an object.
 
 :Returns: 
 
-    out : str
+    out: `str`
 
 :Examples:
 
@@ -2156,13 +2160,13 @@ For example, ``a[...] = broadcast_array(a, b.shape)`` is equivalent to
     
 :Parameters:
   
-    a : numpy array-like
+    a: numpy array-like
     
-    shape : tuple
+    shape: `tuple`
     
 :Returns:
 
-    out : numpy array
+    out: `numpy.ndarray`
     
 :Examples:
 
@@ -2236,20 +2240,20 @@ between ``a`` and ``b``.
 
 :Parameters:
 
-    x, y : array_like
+    x, y: array_like
         Input arrays to compare.
 
-    atol : float, optional
+    atol: `float`, optional
         The absolute tolerance for all numerical comparisons, By
         default the value returned by the `ATOL` function is used.
 
-    rtol : float, optional
+    rtol: `float`, optional
         The relative tolerance for all numerical comparisons, By
         default the value returned by the `RTOL` function is used.
 
 :Returns:
 
-    out : bool
+    out: `bool`
         Returns True if the arrays are equal, otherwise False.
 
 :Examples:
@@ -2276,53 +2280,51 @@ between ``a`` and ``b``.
 
 def _section(o, axes=None, data=False, stop=None, chunks=False,
              min_step=1, **kwargs):
-    '''
-
-Return a list of m dimensional sections of a Field of n dimensions or
+    '''Return a list of m dimensional sections of a Field of n dimensions or
 a dictionary of m dimensional sections of a Data object of n
 dimensions, where m <= n. In the case of a Data object the keys of the
 dictionary are the indicies of the sections in the original Data
 object. The m dimensions that are not sliced are marked with None as a
 placeholder making it possible to reconstruct the original data
 object. The corresponding values are the resulting sections of type
-cf.Data.
+`cf.Data`.
 
 :Parameters:
 
-    axes : *optional*
+    axes: *optional*
         In the case of a Field this is a query for the m axes that
         define the sections of the Field as accepted by the Field
-        object's axes method.  The keyword arguments are also passed
-        to this method. See `cf.Field.axes` for details. If an axis is
+        object's axes method. The keyword arguments are also passed to
+        this method. See `cf.Field.axes` for details. If an axis is
         returned that is not a data axis it is ignored, since it is
         assumed to be a dimension coordinate of size 1. In the case of
         a Data object this should be a tuple or a list of the m
         indices of the m axes that define the sections of the Data
         object. If axes is None (the default) all axes are selected.
     
-    data : bool, optional
+    data: `bool`, optional
         If True this indicates that a data object has been passed, if
         False it indicates that a field object has been passed. By
         default it is False.
 
-    stop : int, optional
+    stop: `int`, optional
         Stop after taking this number of sections and return. If stop
         is None all sections are taken.
     
-    chunks : bool, optional
+    chunks: `bool`, optional
         If True return sections that are of the maximum possible size
         that will fit in one chunk of memory instead of sectioning
         into slices of size 1 along the dimensions that are being
         sectioned.
     
-    min_step : int, optional
+    min_step: `int`, optional
         The minimum step size when making chunks. By default this is
         1. Can be set higher to avoid size 1 dimensions, which are
         problematic for bilinear regridding.
 
 :Returns:
 
-    out : list or dict
+    out: `list` or `dict`
         The list of m dimensional sections of the Field or the
         dictionary of m dimensional sections of the Data object.
 
@@ -2436,12 +2438,13 @@ names:
 #--- End: def
 
 def environment(display=True):
-    ''':Parameters:
+    '''Return the names and versions of cf-python dependencies.
+
+:Parameters:
 
     display: `bool`, optional
-        If False then{+,fef,} return the description of the
-        environment as a string. By default the description is
-        printed.
+        If False then return the description of the environment as a
+        string. By default the description is printed.
 
 :Returns:
 
@@ -2463,7 +2466,7 @@ psutil: 5.0.1 /home/space/anaconda2/lib/python2.7/site-packages/psutil/__init__.
 matplotlib: 1.5.1 /home/space/anaconda2/lib/python2.7/site-packages/matplotlib/__init__.pyc
 ESMF: 7.0.0 /home/space/anaconda2/lib/python2.7/site-packages/ESMF/__init__.pyc
 cfplot: 2.1.10 /home/space/anaconda2/lib/python2.7/site-packages/cfplot/__init__.pyc
-cf2: 2.0 /home/space/cf-python/cf/__init__.pyc
+cf: 2.0.2 /home/space/cf-python/cf/__init__.pyc
 
     '''
     out = []
@@ -2496,7 +2499,7 @@ cf2: 2.0 /home/space/cf-python/cf/__init__.pyc
     else:
         out.append('cfplot: ' + str(cfplot.__version__) + ' ' + str(os_path_abspath(cfplot.__file__)))
             
-    out.append('cf2: ' + str(__version__) + ' ' + str(os_path_abspath(__file__)))
+    out.append('cf: ' + str(__version__) + ' ' + str(os_path_abspath(__file__)))
     
     out = '\n'.join(out)
 
@@ -2505,98 +2508,3 @@ cf2: 2.0 /home/space/cf-python/cf/__init__.pyc
     else:
         return out
 #--- End: def
-
-def get_relative_vorticity(u, v, cyclic=None, missing_values_at_boundary=False):
-    '''
-
-Calculate the relative vorticity using centred finite
-differences. According to the formula given here:
-
-https://www.ncl.ucar.edu/Document/Functions/Built-in/uv2vr_cfd.shtml
-
-"According to H.B. Bluestein [Synoptic-Dynamic Meteorology in
-Midlatitudes, 1992, Oxford Univ. Press p113-114], let D represent the
-partial derivative, a the radius of the earth, phi the latitude and
-dx2/dy2 the appropriate longitudinal and latitudinal spacing,
-respectively. Then, letting j be the latitude y-subscript, and i be
-the longitude x-subscript:
-
-    rv = Dv/Dx - Du/Dy + (u/a)*tan(phi)
-
-
-    rv(j,i) = (v(j,i+1)-v(j,i-1))/dx2(j)
-              - (u(j+1,i)-u(j-1,i))/dy2(j)
-              + (u(j,i)/a)*tan(phi(j))
-
-The last term accounts for the convergence of the meridians on a
-sphere."
-
-The grid may be global or limited area. If missing values are present
-then missing values will be returned at points where the centred
-finite difference could not be calculated. The boundary conditions may
-be cyclic in longitude. The noncyclic boundaries may either be filled
-with missing values or calculated with off-centre finite differences.
-
-:Parameters:
-
-    u: cf.Field
-        A field containing the x-wind. Must be on the same grid as the
-        y-wind.
-
-    v: cf.Field
-        A field containing the y-wind. Must be on the same grid as the
-        x-wind.
-
-    cyclic: `bool`, optional
-        Whether the longitude is cyclic or not. By default this is
-        autodetected.
-
-    missing_values_at_boundary: `bool`, optional
-        If True then the noncyclic boundaries are filled with missing
-        values. By default it is false and off-centre finite
-        differences are calculated at the boundaries.
-
-:Returns:
-
-    rv: cf.Field
-        The relative vorticity calculated with centred finite
-        differences.
-
-    '''
-
-    # Get the longitude and latitude coordinates
-    u_axis_keys, u_axis_sizes, u_coords = u._regrid_get_latlong('u',
-                                                                return_2D=False)
-    v_axis_keys, v_axis_sizes, v_coords = v._regrid_get_latlong('v',
-                                                                return_2D=False)
-
-    if (not u_coords[0].equals(v_coords[0]) or
-        not u_coords[1].equals(v_coords[1])):
-        raise ValueError('u and v must be on the same grid.')
-    #--- End: if
-
-    # Check for cyclicity
-    if cyclic is None:
-        x_bounds = u_coords[0].get_bounds(create=True)
-        cyclic = abs(x_bounds.datum(-1) - x_bounds.datum(0)) == Data(360,
-                                                                     'degrees')
-    #--- End: if
-
-    # Set boundary conditions
-    if missing_values_at_boundary:
-        x_mode = y_mode = 'constant'
-    else:
-        x_mode = y_mode = 'nearest'
-    #--- End: if
-    if cyclic:
-        x_mode = 'wrap'
-    #--- End: if
-
-    # Copy the longitude and latitude coordinates and convert to radians
-    lon = u_coords[0].copy()
-    lon.units = 'radians'
-    lat = u_coords[1].copy()
-    lat.units = 'radians'
-
-    
-#--- End: def
