@@ -975,7 +975,8 @@ Create a field for a given netCDF variable.
                 print '    Inserting dimension coordinate:', repr(coord)
             dim = f.insert_dim(coord, copy=False)
             # Record the netCDF dimension name for this axis
-            f.Axes[dim].ncdim = ncdim
+#            f.Axes[dim].ncdim = ncdim
+            f.axes()[dim].ncdim = ncdim
 
             # Set unlimited status of axis
             if nc.dimensions[ncdim].isunlimited():
@@ -996,7 +997,8 @@ Create a field for a given netCDF variable.
                 print '    Inserting axis:', repr(axis)
             dim = f.insert_axis(axis)
             # Record the netCDF dimension name for this axis
-            f.Axes[dim].ncdim = ncdim
+#            f.Axes[dim].ncdim = ncdim
+            f.axes()[dim].ncdim = ncdim
             
             # Set unlimited status of axis
             try:
@@ -1068,7 +1070,8 @@ Create a field for a given netCDF variable.
                         print '    Inserting axis:', repr(axis)
                     dim = f.insert_axis(axis)
                     # Record the netCDF dimension name for this axis
-                    f.Axes[dim].ncdim = ncdim                    
+#                    f.Axes[dim].ncdim = ncdim                    
+                    f.axes()[dim].ncdim = ncdim
                     dimensions = [dim]
                 else:  
                     # Numeric valued scalar coordinate
@@ -1082,7 +1085,8 @@ Create a field for a given netCDF variable.
                     print '    Inserting dimension coordinate:', repr(coord)
                 dim = f.insert_dim(coord, copy=False)
                 # Record the netCDF dimension name for this axis
-                f.Axes[dim].ncdim = ncvar
+#                f.Axes[dim].ncdim = ncvar
+                f.axes()[dim].ncdim = ncvar
                 dimensions = [dim]
                 ncvar_to_key[ncvar] = dim
                 dimension_coordinates[ncvar] = coord
