@@ -424,6 +424,16 @@ def read1(*args, **kwargs):
     '''``f=cf.read1(*args, **kwargs)`` is equivalent to ``f=cf.read(*args,
 nfields=1, **kwargs)[0]``
 
+    '''
+    print "WARNING: Use cf.read_field in favour of cf.read1. cf.read1 will be deprecated at a later version"
+    return read_field(*args, **kwargs)
+#--- End: def
+
+
+def read_field(*args, **kwargs):
+    '''``f=cf.read_field(*args, **kwargs)`` is equivalent to ``f=cf.read(*args,
+nfields=1, **kwargs)[0]``
+
     '''
     kwargs['nfields'] = 1
     return read(*args, **kwargs)[0]
