@@ -23,7 +23,7 @@ regridding through ESMPY and the associated utility methods.
     """
     
     def __init__(self, srcfield, dstfield, srcfracfield, dstfracfield,
-                 method='conservative', ignore_degenerate=None):
+                 method='conservative', ignore_degenerate=False):
         """
 
 Creates a handle for regridding fields from a source grid to a
@@ -78,9 +78,12 @@ destination grid that can then be used by the run_regridding method.
         else:
             raise ValueError('Regrid method not recognised.')
         
-        self.regridSrc2Dst = ESMF.Regrid(srcfield, dstfield, regrid_method=regrid_method,
-                                         src_mask_values=numpy_array([0], dtype='int32'),
-                                         dst_mask_values=numpy_array([0], dtype='int32'),
+        self.regridSrc2Dst = ESMF.Regrid(srcfield, dstfield, 
+                                         regrid_method=regrid_method,
+                                         src_mask_values=numpy_array([0],
+                                                                dtype='int32'),
+                                         dst_mask_values=numpy_array([0],
+                                                                dtype='int32'),
                                          src_frac_field=srcfracfield,
                                          dst_frac_field=dstfracfield,
                                          unmapped_action=ESMF.UnmappedAction.IGNORE,
@@ -147,8 +150,9 @@ associated mask.
         by default. 
 
     cyclic : `bool`, optional
-        Whether or not the longitude (if present) is cyclic, False
-        by default.
+        Whether or not the longitude (if present) is cyclic. If None
+        the a check for cyclicity is made from the bounds. None by
+        default.
         
     coords_2D : `bool`, optional
         Whether the coordinates are 2D or not. Presently only works
@@ -184,21 +188,21 @@ associated mask.
 
             if use_bounds:
                 if not coords_2D:
-                    # Get the bounds, creating them if they do not exist
-                    x_bounds = lon.get_bounds(create=True)
-                    y_bounds = lat.get_bounds(create=True).clip(-90, 90, 'degrees').array
+                    # Get the bounds
+                    x_bounds = lon.get_bounds()
+                    y_bounds = lat.get_bounds().clip(-90, 90, 'degrees').array
                     
-                    # If not set as cyclic already, check for cyclicity
-                    if not cyclic:
-                        cyclic = abs(x_bounds.datum(-1) 
+                    # If cyclic not set already, check for cyclicity
+                    if cyclic is None:
+                        cyclic = abs(x_bounds.datum(-1)
                                      - x_bounds.datum(0)) == Data(360,
                                                                   'degrees')
                     #--- End: if
                     x_bounds = x_bounds.array
                 else:
-                    # Check whether bounds exist or not, and get them if they do
-                    x_bounds = lon.bounds
-                    y_bounds = lat.bounds.clip(-90, 90, 'degrees')
+                    # Get the bounds
+                    x_bounds = lon.get_bounds()
+                    y_bounds = lat.get_bounds().clip(-90, 90, 'degrees')
                     n = x_bounds.shape[0]
                     m = x_bounds.shape[1]
                     x_bounds = x_bounds.array
@@ -221,12 +225,16 @@ associated mask.
                 #--- End: if
             else:
                 if not coords_2D:
-                    # If not set as cyclic already, check for cyclicity
-                    if not cyclic:
-                        x_bounds = lon.get_bounds(create=True)
-                        cyclic = abs(x_bounds.datum(-1) 
-                                     - x_bounds.datum(0)) == Data(360,
-                                                                  'degrees')
+                    # If cyclicity not set already, check for cyclicity
+                    if cyclic is None:
+                        try:
+                            x_bounds = lon.get_bounds()
+                            cyclic = abs(x_bounds.datum(-1) 
+                                         - x_bounds.datum(0)) == Data(360,
+                                                                      'degrees')
+                        except ValueError:
+                            pass
+                        #--- End: try
                     #--- End: if
                 #--- End: if
             #--- End: if
@@ -239,7 +247,8 @@ associated mask.
                 staggerLocs = [ESMF.StaggerLoc.CENTER]
             #--- End: if
             if cyclic:
-                grid = ESMF.Grid(max_index, num_peri_dims=1, staggerloc=staggerLocs)
+                grid = ESMF.Grid(max_index, num_peri_dims=1,
+                                 staggerloc=staggerLocs)
             else:
                 grid = ESMF.Grid(max_index, staggerloc=staggerLocs)
             #--- End: if
@@ -296,14 +305,13 @@ associated mask.
             # For 1D conservative regridding add an extra dimension of size 1
             if ndim == 1:
                 if not use_bounds:
-                    # For 1D nonconservative  regridding the extra dimension should
-                    # already have been added in cf.Field.regridc.
-                    raise ValueError('Cannot create a Cartesian grid from one ' +
-                                     'dimension coordinate with no bounds.')
+                    # For 1D nonconservative regridding the extra dimension
+                    # should already have been added in cf.Field.regridc.
+                    raise ValueError('Cannot create a Cartesian grid from ' +
+                                     'one dimension coordinate with no bounds.')
                 coords = [DimensionCoordinate(data=Data(0),
-                                              bounds=Data([numpy_finfo('float32').epsneg,
-                                                           numpy_finfo('float32').eps]))] \
-                         + coords
+                          bounds=Data([numpy_finfo('float32').epsneg,
+                                       numpy_finfo('float32').eps]))] + coords
                 if mask is not None:
                     mask = mask[None,:]
                 ndim = 2
@@ -317,7 +325,8 @@ associated mask.
             max_index = numpy_array(shape, dtype='int32')
             if use_bounds:
                 if ndim < 3:
-                    staggerLocs = [ESMF.StaggerLoc.CORNER, ESMF.StaggerLoc.CENTER]
+                    staggerLocs = [ESMF.StaggerLoc.CORNER,
+                                   ESMF.StaggerLoc.CENTER]
                 else:
                     staggerLocs = [ESMF.StaggerLoc.CENTER_VCENTER,
                                    ESMF.StaggerLoc.CORNER_VFACE]
@@ -335,11 +344,13 @@ associated mask.
             # Populate the grid centres
             for d in xrange(0, ndim):
                 if ndim < 3:
-                    gridCentre = grid.get_coords(d, staggerloc=ESMF.StaggerLoc.CENTER)
+                    gridCentre = grid.get_coords(d,
+                                     staggerloc=ESMF.StaggerLoc.CENTER)
                 else:
-                    gridCentre = grid.get_coords(d, staggerloc=ESMF.StaggerLoc.CENTER_VCENTER)
-                gridCentre[...] = coords[d].array.reshape([shape[d] if x == d else 1
-                                                           for x in xrange(0, ndim)])
+                    gridCentre = grid.get_coords(d,
+                                     staggerloc=ESMF.StaggerLoc.CENTER_VCENTER)
+                gridCentre[...] = coords[d].array.reshape(
+                    [shape[d] if x == d else 1 for x in xrange(0, ndim)])
                 #--- End: if
             #--- End: for
             
@@ -358,8 +369,9 @@ associated mask.
                         tmp[-1] = boundsD[-1, 1]
                         boundsD = tmp
                     #--- End: if
-                    gridCorner[d][...] = boundsD.reshape([shape[d] + 1 if x == d else 1
-                                                          for x in xrange(0, ndim)])
+                    gridCorner[d][...] = boundsD.reshape(
+                        [shape[d] + 1 if x == d else 1
+                         for x in xrange(0, ndim)])
                 #--- End: for
             #--- End: if
         #--- End: if
