@@ -33,6 +33,7 @@ class DataTest(unittest.TestCase):
     test_only = []
 #    test_only = ['NOTHING!!!!!']
 #    test_only = ['test_Data__asdatetime__asreftime__isdatetime']
+#    test_only = ['test_Data_binary_mask']
 #    test_only = ['test_Data_AUXILIARY_MASK']
 #    test_only = ['test_Data__collapse_UNWEIGHTED_MASKED']
 #    test_only = ['test_Data__collapse_UNWEIGHTED_UNMASKED']
@@ -337,6 +338,30 @@ class DataTest(unittest.TestCase):
         cf.CHUNKSIZE(self.original_chunksize)
     #--- End: def
 
+    def test_Data_binary_mask(self):
+        if self.test_only and inspect.stack()[0][3] not in self.test_only:
+            return
+
+        a = numpy.ma.ones((1000,), dtype='int32')
+        a[[1, 900]] = numpy.ma.masked
+        a[[0, 10, 910]] = 0
+        
+        for chunksize in self.chunk_sizes:   
+            cf.CHUNKSIZE(chunksize)
+
+            d = cf.Data(numpy.arange(1000.), 'radians')
+            d[[1, 900]] = cf.masked
+            d[[10, 910]] = 0
+
+            b = d.binary_mask
+
+            self.assertTrue(b.Units == cf.Units('1'))
+            self.assertTrue(b.dtype == numpy.dtype('int32'))
+            self.assertTrue((b.array == a).all())
+
+        cf.CHUNKSIZE(self.original_chunksize)
+    #--- End: def
+    
     def test_Data_clip(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
@@ -1510,7 +1535,7 @@ class DataTest(unittest.TestCase):
         for chunksize in self.chunk_sizes:   
             cf.CHUNKSIZE(chunksize) 
             
-            d = cf.read1(self.filename).data
+            d = cf.read(self.filename)[0].data
             
             dumpd = d.dumpd()
             self.assertTrue(d.equals(cf.Data(loadd=d.dumpd()), traceback=True))
@@ -1527,7 +1552,7 @@ class DataTest(unittest.TestCase):
 
         for chunksize in (300, 10000, 100000)[::-1]:
             cf.CHUNKSIZE(chunksize)
-            f = cf.read1(self.filename6)
+            f = cf.read(self.filename6)[0]
             self.assertTrue(list(sorted(f.Data.section((1,2)).keys()))
                             == [(x, None, None) for x in range(1800)])
         #--- End: for
