@@ -18,7 +18,7 @@ class FieldTest(unittest.TestCase):
         
         self.chunk_sizes = (17, 34, 300, 100000)[::-1]
         self.original_chunksize = cf.CHUNKSIZE()
-        self.f = cf.read1(self.filename)
+        self.f = cf.read(self.filename)[0]
 
         self.test_only = []
 #        self.test_only = ['test_Field_AUXILIARY_MASK']
@@ -167,9 +167,9 @@ class FieldTest(unittest.TestCase):
 
         for chunksize in self.chunk_sizes:
             cf.CHUNKSIZE(chunksize)
-            f = cf.read1(self.filename).squeeze()
+            f = cf.read(self.filename)[0].squeeze()
             d = f.data
-            f = cf.read1(self.filename).squeeze()
+            f = cf.read(self.filename)[0].squeeze()
 
             g = f[...]
             self.assertTrue((g.data == d).all())
@@ -207,7 +207,7 @@ class FieldTest(unittest.TestCase):
 
         for chunksize in self.chunk_sizes:
             cf.CHUNKSIZE(chunksize)
-            f = cf.read1(self.filename).squeeze()
+            f = cf.read(self.filename)[0].squeeze()
 
             f[...] = 0
             self.assertTrue((f == 0).all())
@@ -231,7 +231,7 @@ class FieldTest(unittest.TestCase):
 
         for chunksize in self.chunk_sizes:
             cf.CHUNKSIZE(chunksize)
-            f = cf.read1(self.filename).squeeze()
+            f = cf.read(self.filename)[0].squeeze()
             g = f.copy()
             f_plus_g = f + g
             g_plus_f = g + f
@@ -257,7 +257,7 @@ class FieldTest(unittest.TestCase):
       
         for chunksize in self.chunk_sizes:
             cf.CHUNKSIZE(chunksize)
-            f = cf.read1(self.filename)
+            f = cf.read(self.filename)[0]
 
             for period in (dimarray.min()-5, dimarray.min()):
                 anchors = numpy.arange(dimarray.min()-3*period,
@@ -334,7 +334,7 @@ class FieldTest(unittest.TestCase):
 
         for chunksize in self.chunk_sizes:    
             cf.CHUNKSIZE(chunksize)
-            f = cf.read1(self.filename)
+            f = cf.read(self.filename)[0]
             g = f.copy()
             self.assertTrue(f.equals(g, traceback=True))
             self.assertFalse(f.equals(g+1, traceback=False))
@@ -346,7 +346,7 @@ class FieldTest(unittest.TestCase):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
-        f = cf.read1(self.filename)
+        f = cf.read(self.filename)[0]
         
         g = f.copy()   
         g.expand_dims(i=1)
@@ -383,7 +383,7 @@ class FieldTest(unittest.TestCase):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
-        f = cf.read1(self.filename)
+        f = cf.read(self.filename)[0]
 
         self.assertTrue(len(f.Items()) == 16)
         self.assertTrue(len(f.Items(role='damr')) == 9)
@@ -468,7 +468,7 @@ class FieldTest(unittest.TestCase):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
-        f = cf.read1(self.filename)
+        f = cf.read(self.filename)[0]
         f.long_name = 'qwerty'
         f.ncvar = 'tas'
         all_kwargs = (
@@ -522,7 +522,7 @@ class FieldTest(unittest.TestCase):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
-        f = cf.read1(self.filename)
+        f = cf.read(self.filename)[0]
         f.dim('X').period(None)
         f.cyclic('X', False)
         self.assertTrue(f.period('X') is None)
@@ -540,7 +540,7 @@ class FieldTest(unittest.TestCase):
 
         for chunksize in self.chunk_sizes:
             cf.CHUNKSIZE(chunksize)
-            f = cf.read1(self.filename2)[0:100]
+            f = cf.read(self.filename2)[0][0:100]
             self.assertTrue(len(f.section(('X','Y'))) == 100,
                             'CHUNKSIZE = %s' % chunksize)
         #--- End: for
@@ -551,7 +551,7 @@ class FieldTest(unittest.TestCase):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
-        f = cf.read1(self.filename)
+        f = cf.read(self.filename)[0]
 
         f.squeeze(i=True)
         g = f.copy()
@@ -565,7 +565,7 @@ class FieldTest(unittest.TestCase):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
-        f = cf.read1(self.filename)
+        f = cf.read(self.filename)[0]
 
         # Null tranpose
         self.assertTrue(f is f.transpose([0, 1, 2], i=True))
