@@ -47,6 +47,15 @@ class read_writeTest(unittest.TestCase):
                         'Bad read with select keyword')
     #--- End: def
 
+    def test_read_field(self):
+        if self.test_only and inspect.stack()[0][3] not in self.test_only:
+            return
+
+        f = cf.read(self.filename)
+        g = cf.read_field(self.filename)
+        self.assertTrue(f.equals(g, traceback=True))
+    #--- End: def
+
     def test_read_field(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
@@ -120,7 +129,7 @@ class read_writeTest(unittest.TestCase):
             self.assertTrue(f.dtype == numpy.dtype(float))
             cf.write(f, tmpfile, fmt='NETCDF4', 
                      datatype={numpy.dtype(float): numpy.dtype('float32')})
-            g = cf.read1(tmpfile)
+            g = cf.read(tmpfile)[0]
             self.assertTrue(g.dtype == numpy.dtype('float32'), 
                             'datatype read in is '+str(g.dtype))
         #--- End: for
@@ -140,7 +149,7 @@ class read_writeTest(unittest.TestCase):
                 dim = f.insert_axis(cf.DomainAxis(1))
                 f.insert_dim(t, key=dim)
                 cf.write(f, tmpfile, fmt='NETCDF4', reference_datetime=reference_datetime)
-                g = cf.read1(tmpfile)
+                g = cf.read(tmpfile)[0]
                 t = g.dim('T')
                 self.assertTrue(t.Units == cf.Units('days since '+reference_datetime),
                                 'Units written were '+repr(t.Units.reftime)+' not '+repr(reference_datetime))
@@ -173,7 +182,7 @@ class read_writeTest(unittest.TestCase):
             cf.write(f, tmpfile, fmt=fmt)
             f.unlimited(org)
             
-            g = cf.read1(tmpfile)
+            g = cf.read(tmpfile)[0]
             self.assertTrue(g.unlimited()[g.axis(axis, key=True)] is True,
                             'Failed with axis={}, fmt={}'.format(axis, fmt))
 
@@ -183,7 +192,7 @@ class read_writeTest(unittest.TestCase):
             cf.write(f, tmpfile, fmt=fmt)
             f.unlimited(org)
             
-            g = cf.read1(tmpfile)
+            g = cf.read(tmpfile)[0]
             self.assertTrue(g.unlimited()[g.axis(axis, key=True)] is True,
                             'Failed with axis={}, fmt={}'.format(axis, fmt))
 
@@ -192,7 +201,7 @@ class read_writeTest(unittest.TestCase):
         cf.write(f, tmpfile, fmt=fmt)
         f.unlimited(org)
 
-        g = cf.read1(tmpfile)
+        g = cf.read(tmpfile)[0]
         self.assertTrue(g.unlimited()[g.axis('X', key=True)] is True,
                         'Failed with axis={}, fmt={}'.format('X', fmt))
         self.assertTrue(g.unlimited()[g.axis('Y', key=True)] is True,
@@ -204,7 +213,7 @@ class read_writeTest(unittest.TestCase):
         cf.write(f, tmpfile, fmt=fmt, unlimited=['X'])
         f.unlimited(org)
 
-        g = cf.read1(tmpfile)
+        g = cf.read(tmpfile)[0]
         self.assertTrue(not g.unlimited()[g.axis('X', key=True)],
                         'Failed with axis={}, fmt={}'.format('X', fmt))
 
@@ -214,7 +223,7 @@ class read_writeTest(unittest.TestCase):
         cf.write(f, tmpfile, fmt=fmt, unlimited=['X'])
         f.unlimited(org)
 
-        g = cf.read1(tmpfile)
+        g = cf.read(tmpfile)[0]
         self.assertTrue(g.unlimited()[g.axis('X', key=True)] is True,
                         'Failed with axis={}, fmt={}'.format('X', fmt))
 
@@ -224,7 +233,7 @@ class read_writeTest(unittest.TestCase):
         cf.write(f, tmpfile, fmt=fmt, unlimited=['X'])
         f.unlimited(org)
 
-        g = cf.read1(tmpfile)
+        g = cf.read(tmpfile)[0]
         self.assertTrue(g.unlimited()[g.axis('X', key=True)] is True,
                         'Failed with axis={}, fmt={}'.format('X', fmt))
         self.assertTrue(g.unlimited()[g.axis('Y', key=True)] is True,
@@ -237,7 +246,7 @@ class read_writeTest(unittest.TestCase):
         cf.write(f, tmpfile, fmt=fmt)
         f.unlimited(org)
 
-        g = cf.read1(tmpfile)
+        g = cf.read(tmpfile)[0]
         self.assertTrue(g.unlimited()[g.axis('X', key=True)] is True,
                         'Failed with axis={}, fmt={}'.format('X', fmt))
         self.assertTrue(g.unlimited()[g.axis('Y', key=True)] is True,
@@ -251,7 +260,7 @@ class read_writeTest(unittest.TestCase):
         cf.write(f, tmpfile, fmt=fmt)
         f.unlimited(org)
 
-        g = cf.read1(tmpfile)
+        g = cf.read(tmpfile)[0]
         self.assertTrue(not g.unlimited()[g.axis('X', key=True)],
                         'Failed with axis={}, fmt={}'.format('X', fmt))
         self.assertTrue(not g.unlimited()[g.axis('Y', key=True)],
